@@ -819,7 +819,7 @@ class BaseSchema(base.SchemaABC):
                 else:
                     obj_prototype = next(iter(obj))
             except (StopIteration, IndexError):  # Nothing to serialize
-                return self.declared_fields
+                return dict((k, v) for k, v in self.declared_fields.items() if k in field_names)
             obj = obj_prototype
         ret = self.dict_class()
         for key in field_names:
@@ -886,7 +886,7 @@ class BaseSchema(base.SchemaABC):
                         validated_value = unmarshal.call_and_store(
                             getter_func=validator,
                             data=value,
-                            field_name=field_name,
+                            field_name=field_obj.load_from or field_name,
                             field_obj=field_obj,
                             index=(idx if self.opts.index_errors else None)
                         )
@@ -901,7 +901,7 @@ class BaseSchema(base.SchemaABC):
                     validated_value = unmarshal.call_and_store(
                         getter_func=validator,
                         data=value,
-                        field_name=field_name,
+                        field_name=field_obj.load_from or field_name,
                         field_obj=field_obj
                     )
                     if validated_value is missing:
